@@ -624,25 +624,25 @@ void clear_matching_info_variable()
 {
     char buf[128];
     snprintf(buf, 128, "");
-    hash_put(gRootObject, "MATCH", STRING_NEW_GC(buf, FALSE));
+    uobject_put(gRootObject, "MATCH", STRING_NEW_GC(buf, FALSE));
 
     snprintf(buf, 128, "");
-    hash_put(gRootObject, "PREMATCH", STRING_NEW_GC(buf, FALSE));
+    uobject_put(gRootObject, "PREMATCH", STRING_NEW_GC(buf, FALSE));
 
     snprintf(buf, 128, "");
-    hash_put(gRootObject, "POSTMATCH", STRING_NEW_GC(buf, FALSE));
+    uobject_put(gRootObject, "POSTMATCH", STRING_NEW_GC(buf, FALSE));
 
     snprintf(buf, 128, "");
-    hash_put(gRootObject, "MATCH_NUMBER", STRING_NEW_GC(buf, FALSE));
+    uobject_put(gRootObject, "MATCH_NUMBER", STRING_NEW_GC(buf, FALSE));
 
     snprintf(buf, 128, "");
-    hash_put(gRootObject, "LAST_MATCH", STRING_NEW_GC(buf, FALSE));
+    uobject_put(gRootObject, "LAST_MATCH", STRING_NEW_GC(buf, FALSE));
 
     int i;
     for(i=0; i<10; i++) {
         char name[128];
         snprintf(name, 128, "%d", i);
-        hash_put(gRootObject, name, STRING_NEW_GC(buf, FALSE));
+        uobject_put(gRootObject, name, STRING_NEW_GC(buf, FALSE));
     }
 }
 
@@ -690,17 +690,17 @@ BOOL cmd_condition_re(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             if(r2 >= 0) {
                 if(region->beg[0] > 0) {
-                    hash_put(gRootObject, "PREMATCH", STRING_NEW_GC3(target, region->beg[0], FALSE));
+                    uobject_put(gRootObject, "PREMATCH", STRING_NEW_GC3(target, region->beg[0], FALSE));
                 }
 
                 const int size = region->end[0] - region->beg[0];
 
-                hash_put(gRootObject, "MATCH", STRING_NEW_GC3(target + region->beg[0], size, FALSE));
-                hash_put(gRootObject, "0", STRING_NEW_GC3(target + region->beg[0], size, FALSE));
+                uobject_put(gRootObject, "MATCH", STRING_NEW_GC3(target + region->beg[0], size, FALSE));
+                uobject_put(gRootObject, "0", STRING_NEW_GC3(target + region->beg[0], size, FALSE));
 
                 const int n = strlen(target)-region->end[0];
                 if(n > 0) {
-                    hash_put(gRootObject, "POSTMATCH", STRING_NEW_GC3(target + region->end[0], n, FALSE));
+                    uobject_put(gRootObject, "POSTMATCH", STRING_NEW_GC3(target + region->end[0], n, FALSE));
                 }
 
                 int i;
@@ -710,7 +710,7 @@ BOOL cmd_condition_re(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                     char name[16];
                     snprintf(name, 16, "%d", i);
 
-                    hash_put(gRootObject, name, STRING_NEW_GC3(target + region->beg[i], size, FALSE));
+                    uobject_put(gRootObject, name, STRING_NEW_GC3(target + region->beg[i], size, FALSE));
                 }
 
                 if(region->num_regs > 0) {
@@ -718,12 +718,12 @@ BOOL cmd_condition_re(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                     const int size = region->end[n] - region->beg[n];
 
-                    hash_put(gRootObject, "LAST_MATCH", STRING_NEW_GC3(target + region->beg[n], size, FALSE));
+                    uobject_put(gRootObject, "LAST_MATCH", STRING_NEW_GC3(target + region->beg[n], size, FALSE));
                 }
 
                 char buf[128];
                 snprintf(buf, 128, "%d", region->num_regs);
-                hash_put(gRootObject, "MATCH_NUMBER", STRING_NEW_GC(buf, FALSE));
+                uobject_put(gRootObject, "MATCH_NUMBER", STRING_NEW_GC(buf, FALSE));
 
                 if(verbose) {
                     int point = str_pointer2kanjipos(code, target, target + r2);
