@@ -1002,7 +1002,7 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         p++;
 
                         char* arg;
-                        if(strings_num < vector_size(SFD(nextin).fdbuf.mLines)) {
+                        if(strings_num < vector_count(SFD(nextin).fdbuf.mLines)) {
                             arg = vector_item(SFD(nextin).fdbuf.mLines, strings_num);
                         }
                         else {
@@ -1027,7 +1027,7 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         p++;
 
                         char* arg;
-                        if(strings_num < vector_size(SFD(nextin).fdbuf.mLines)) {
+                        if(strings_num < vector_count(SFD(nextin).fdbuf.mLines)) {
                             arg = vector_item(SFD(nextin).fdbuf.mLines, strings_num);
                         }
                         else {
@@ -1051,7 +1051,7 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                         p++;
 
                         sObject* arg;
-                        if(strings_num < vector_size(SFD(nextin).fdbuf.mLines)) {
+                        if(strings_num < vector_count(SFD(nextin).fdbuf.mLines)) {
                             arg = STRING_NEW_STACK(vector_item(SFD(nextin).fdbuf.mLines, strings_num));
                         }
                         else {
@@ -1086,7 +1086,7 @@ BOOL cmd_printf(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
             }
         }
 
-        if(strings_num > vector_size(SFD(nextin).fdbuf.mLines)) {
+        if(strings_num > vector_count(SFD(nextin).fdbuf.mLines)) {
             if(SFD(nextin).fdbuf.mBufLen == 0) {
                 runinfo->mRCode = RCODE_NFUN_NULL_INPUT;
             }
@@ -1177,17 +1177,17 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                         const int size = region->beg[0] - (p - target);
                         if(size > 0) {
-                            hash_put(gRootObject, "PREMATCH", STRING_NEW_GC3(p, size, FALSE));
+                            uobject_put(gRootObject, "PREMATCH", STRING_NEW_GC3(p, size, FALSE));
                         }
 
                         const int size2 = region->end[0] - region->beg[0];
 
-                        hash_put(gRootObject, "MATCH", STRING_NEW_GC3(target + region->beg[0], size2, FALSE));
-                        hash_put(gRootObject, "0", STRING_NEW_GC3(target + region->beg[0], size2, FALSE));
+                        uobject_put(gRootObject, "MATCH", STRING_NEW_GC3(target + region->beg[0], size2, FALSE));
+                        uobject_put(gRootObject, "0", STRING_NEW_GC3(target + region->beg[0], size2, FALSE));
 
                         const int n = strlen(target)-region->end[0];
                         if(n > 0) {
-                            hash_put(gRootObject, "POSTMATCH", STRING_NEW_GC3(target + region->end[0], n, FALSE));
+                            uobject_put(gRootObject, "POSTMATCH", STRING_NEW_GC3(target + region->end[0], n, FALSE));
                         }
 
                         int i;
@@ -1197,7 +1197,7 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                             char name[16];
                             snprintf(name, 16, "%d", i);
 
-                            hash_put(gRootObject, name, STRING_NEW_GC3(target + region->beg[i], size, FALSE));
+                            uobject_put(gRootObject, name, STRING_NEW_GC3(target + region->beg[i], size, FALSE));
                         }
 
                         if(region->num_regs > 0) {
@@ -1205,12 +1205,12 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                             const int size = region->end[n] - region->beg[n];
 
-                            hash_put(gRootObject, "LAST_MATCH", STRING_NEW_GC3(target + region->beg[n], size, FALSE));
+                            uobject_put(gRootObject, "LAST_MATCH", STRING_NEW_GC3(target + region->beg[n], size, FALSE));
                         }
 
                         char buf[128];
                         snprintf(buf, 128, "%d", region->num_regs);
-                        hash_put(gRootObject, "MATCH_NUMBER", STRING_NEW_GC(buf, FALSE));
+                        uobject_put(gRootObject, "MATCH_NUMBER", STRING_NEW_GC(buf, FALSE));
 
                         fd_clear(nextin2);
                         fd_clear(nextout2);
@@ -1358,7 +1358,7 @@ BOOL cmd_sub(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
         char buf[128];
         snprintf(buf, 128, "%d", sub_count);
-        hash_put(gRootObject, "SUB_COUNT", STRING_NEW_GC(buf, FALSE));
+        uobject_put(gRootObject, "SUB_COUNT", STRING_NEW_GC(buf, FALSE));
 
         if(sub_count > 0) {
             if(SFD(nextin).fdbuf.mBufLen == 0) {
@@ -1488,17 +1488,17 @@ BOOL cmd_scan(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                         const int size = region->beg[0] - (p - target);
                         if(size > 0) {
-                            hash_put(gRootObject, "PREMATCH", STRING_NEW_GC3(p, size, FALSE));
+                            uobject_put(gRootObject, "PREMATCH", STRING_NEW_GC3(p, size, FALSE));
                         }
 
                         const int size2 = region->end[0] - region->beg[0];
 
-                        hash_put(gRootObject, "MATCH", STRING_NEW_GC3(target + region->beg[0], size2, FALSE));
-                        hash_put(gRootObject, "0", STRING_NEW_GC3(target + region->beg[0], size2, FALSE));
+                        uobject_put(gRootObject, "MATCH", STRING_NEW_GC3(target + region->beg[0], size2, FALSE));
+                        uobject_put(gRootObject, "0", STRING_NEW_GC3(target + region->beg[0], size2, FALSE));
 
                         const int n = strlen(target)-region->end[0];
                         if(n > 0) {
-                            hash_put(gRootObject, "POSTMATCH", STRING_NEW_GC3(target + region->end[0], n, FALSE));
+                            uobject_put(gRootObject, "POSTMATCH", STRING_NEW_GC3(target + region->end[0], n, FALSE));
                         }
 
                         int i;
@@ -1508,7 +1508,7 @@ BOOL cmd_scan(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
                             char name[16];
                             snprintf(name, 16, "%d", i);
 
-                            hash_put(gRootObject, name, STRING_NEW_GC3(target + region->beg[i], size, FALSE));
+                            uobject_put(gRootObject, name, STRING_NEW_GC3(target + region->beg[i], size, FALSE));
                         }
 
                         if(region->num_regs > 0) {
@@ -1516,12 +1516,12 @@ BOOL cmd_scan(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
                             const int size = region->end[n] - region->beg[n];
 
-                            hash_put(gRootObject, "LAST_MATCH", STRING_NEW_GC3(target + region->beg[n], size, FALSE));
+                            uobject_put(gRootObject, "LAST_MATCH", STRING_NEW_GC3(target + region->beg[n], size, FALSE));
                         }
 
                         char buf[128];
                         snprintf(buf, 128, "%d", region->num_regs);
-                        hash_put(gRootObject, "MATCH_NUMBER", STRING_NEW_GC(buf, FALSE));
+                        uobject_put(gRootObject, "MATCH_NUMBER", STRING_NEW_GC(buf, FALSE));
 
                         int rcode = 0;
                         if(!run(block, nextin2, nextout, &rcode, runinfo->mCurrentObject, runinfo->mRunningObject)) {
@@ -1600,7 +1600,7 @@ BOOL cmd_scan(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 
             char buf[128];
             snprintf(buf, 128, "%d", match_count);
-            hash_put(gRootObject, "MATCH_COUNT", STRING_NEW_GC(buf, FALSE));
+            uobject_put(gRootObject, "MATCH_COUNT", STRING_NEW_GC(buf, FALSE));
 
             if(match_count > 0) {
                 if(SFD(nextin).fdbuf.mBufLen == 0) {
