@@ -39,9 +39,11 @@ static void object_delete(sObject* obj)
         break;
 
     case T_BLOCK:
-    case T_COMPLETION:
         block_delete_gc(obj);
         break;
+        
+    case T_COMPLETION:
+        break;
 
     case T_CLASS:
         class_delete_gc(obj);
@@ -75,8 +77,8 @@ static void object_delete(sObject* obj)
         SEXTOBJ(obj).mFreeFun(SEXTOBJ(obj).mObject);
         break;
 
-    case T_EXTERNAL:
-        external_delete_gc(obj);
+    case T_EXTPROG:
+        external_prog_delete_gc(obj);
         break;
     }
 }
@@ -103,7 +105,7 @@ int object_gc_children_mark(sObject* self)
         break;
 
     case T_CLASS:
-        count += fun_gc_children_mark(self);
+        count += class_gc_children_mark(self);
         break;
 
     case T_FUN:
@@ -115,10 +117,13 @@ int object_gc_children_mark(sObject* self)
         break;
 
     case T_BLOCK:
-    case T_COMPLETION:
         count += block_gc_children_mark(self);
         break;
 
+    case T_COMPLETION:
+        count += completion_gc_children_mark(self);
+        break;
+
     case T_EXTOBJ:
         count += SEXTOBJ(self).mMarkFun(self);
         break;
@@ -195,17 +200,18 @@ void gc_init(int pool_size)
     gCompletionObject = UOBJECT_NEW_GC(8, gRootObject, "compl", FALSE);
     uobject_init(gCompletionObject);
 
-    hash_put(gRootObject, "compl", gCompletionObject);
+    uobject_put(gRootObject, "compl", gCompletionObject);
 
     gxyzshObject = UOBJECT_NEW_GC(8, NULL, "xyzsh", FALSE);
     gStackFrames = VECTOR_NEW_GC(8, FALSE);
-    hash_put(gxyzshObject, "_stackframes", gStackFrames);
+    uobject_put(gxyzshObject, "_stackframes", gStackFrames);
 }
 
 void gc_final()
 {
     /// sweep all user objects ///
-    hash_clear(gRootObject);
+    uobject_clear(gRootObject);
+    uobject_clear(gxyzshObject);
     if(gAppType == kATConsoleApp) {
         printf("sweeped %d objects...\n", gc_sweep());
     }
