@@ -16,9 +16,6 @@ int main(int argc, char** argv)
 {
     CHECKML_BEGIN(FALSE);
 
-    setenv("XYZSH_VERSION", "1.0.5a", 1);
-    setenv("XYZSH_DATAROOTDIR", DATAROOTDIR, 1);
-
     srandom((unsigned)time(NULL));
 
     char* optc = NULL;
@@ -48,11 +45,11 @@ int main(int argc, char** argv)
     }
     else if(file) {
         xyzsh_init(kATOptC, no_runtime_script);
-        xyzsh_load_file(file, argv, argc);
+        (void)xyzsh_load_file(file, argv, argc, gRootObject);
     }
     else {
-        xyzsh_init(kATConsoleApp, no_runtime_script);
         setenv("XYZSH_RUNNING_AS_INTRACTIVE_MODE", "1", 1);
+        xyzsh_init(kATConsoleApp, no_runtime_script);
         xyzsh_readline_interface("", -1, argv, argc);
     }
 
