@@ -632,52 +632,136 @@ BOOL cmd_completion(sObject* nextin, sObject* nextout, sRunInfo* runinfo)
 {
     sCommand* command = runinfo->mCommand;
 
-    if(command->mArgsNumRuntime >= 2 && command->mBlocksNum == 1) {
-        sObject* block = command->mBlocks[0];
+    if(command->mArgsNumRuntime >= 2) {
+        if(command->mBlocksNum == 1) {
+            sObject* block = command->mBlocks[0];
 
-        int i;
-        for(i=1; i<command->mArgsNumRuntime; i++) {
-            sObject* object = gCompletionObject;
+            int i;
+            for(i=1; i<command->mArgsNumRuntime; i++) {
+                sObject* object = gCompletionObject;
 
-            sObject* str = STRING_NEW_GC("", FALSE);
-            char* p = command->mArgsRuntime[i];
-            while(*p) {
-                if(*p == ':' && *(p+1) == ':') {
-                    if(string_c_str(str)[0] == 0) {
-                        err_msg("invalid object name", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
-                        return FALSE;
-                    }
-                    p+=2;
+                sObject* str = STRING_NEW_GC("", FALSE);
+                char* p = command->mArgsRuntime[i];
+                while(*p) {
+                    if(*p == ':' && *(p+1) == ':') {
+                        if(string_c_str(str)[0] == 0) {
+                            err_msg("invalid object name", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            return FALSE;
+                        }
+                        p+=2;
 
-                    sObject* object2 = uobject_item(object, string_c_str(str));
-                    if(object2 == NULL || TYPE(object2) !=T_UOBJECT) {
-                        sObject* new_object = UOBJECT_NEW_GC(8, object, string_c_str(str), TRUE);
-                        uobject_put(object, string_c_str(str), new_object);
-                        uobject_init(new_object);
+                        sObject* object2 = uobject_item(object, string_c_str(str));
+                        if(object2 == NULL || TYPE(object2) !=T_UOBJECT) {
+                            sObject* new_object = UOBJECT_NEW_GC(8, object, string_c_str(str), TRUE);
+                            uobject_put(object, string_c_str(str), new_object);
+                            uobject_init(new_object);
 
-                        object = new_object;
+                            object = new_object;
+                        }
+                        else {
+                            object = object2;
+                        }
+                        string_put(str, "");
                     }
                     else {
-                        object = object2;
+                        string_push_back2(str, *p);
+                        p++;
                     }
-                    string_put(str, "");
+                }
+                if(object && TYPE(object) == T_UOBJECT && string_c_str(str)[0] != 0) {
+                    uobject_put(object, string_c_str(str), COMPLETION_NEW_GC(block, FALSE));
                 }
                 else {
-                    string_push_back2(str, *p);
-                    p++;
+                    err_msg("There is no object", runinfo->mSName, runinfo->mSLine, command->mArgsRuntime[i]);
+
+                    return FALSE;
                 }
             }
-            if(object && TYPE(object) == T_UOBJECT && string_c_str(str)[0] != 0) {
-                uobject_put(object, string_c_str(str), COMPLETION_NEW_GC(block, FALSE));
-            }
-            else {
-                err_msg("There is no object", runinfo->mSName, runinfo->mSLine, command->mArgsRuntime[i]);
 
-                return FALSE;
-            }
+            runinfo->mRCode = 0;
         }
+        else if(command->mBlocksNum == 0) {
+            int i;
+            for(i=1; i<command->mArgsNumRuntime; i++) {
+                sObject* object = gCompletionObject;
 
-        runinfo->mRCode = 0;
+                sObject* str = STRING_NEW_GC("", FALSE);
+                char* p = command->mArgsRuntime[i];
+                while(*p) {
+                    if(*p == ':' && *(p+1) == ':') {
+                        if(string_c_str(str)[0] == 0) {
+                            err_msg("invalid object name", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            return FALSE;
+                        }
+                        p+=2;
+
+                        sObject* object2 = uobject_item(object, string_c_str(str));
+                        if(object2 == NULL || TYPE(object2) !=T_UOBJECT) {
+                            sObject* new_object = UOBJECT_NEW_GC(8, object, string_c_str(str), TRUE);
+                            uobject_put(object, string_c_str(str), new_object);
+                            uobject_init(new_object);
+
+                            object = new_object;
+                        }
+                        else {
+                            object = object2;
+                        }
+                        string_put(str, "");
+                    }
+                    else {
+                        string_push_back2(str, *p);
+                        p++;
+                    }
+                }
+                if(object && TYPE(object) == T_UOBJECT && string_c_str(str)[0] != 0) {
+                    sObject* completion = uobject_item(object, string_c_str(str));
+                    if(completion) {
+                        stack_start_stack();
+
+                        sObject* fun = FUN_NEW_STACK(NULL);
+                        sObject* stackframe = UOBJECT_NEW_GC(8, gxyzshObject, "_stackframe", FALSE);
+                        vector_add(gStackFrames, stackframe);
+                        //uobject_init(stackframe);
+                        SFUN(fun).mLocalObjects = stackframe;
+
+                        xyzsh_set_signal();
+                        int rcode = 0;
+                        if(!run(SCOMPLETION(completion).mBlock, nextin, nextout, &rcode, gRootObject, fun)) {
+                            if(rcode == RCODE_BREAK) {
+                            }
+                            else if(rcode == RCODE_RETURN) {
+                            }
+                            else if(rcode == RCODE_EXIT) {
+                            }
+                            else {
+                                err_msg_adding("run time error\n", runinfo->mSName, runinfo->mSLine, command->mArgs[0]);
+                            }
+
+                            (void)vector_pop_back(gStackFrames);
+                            readline_signal();
+                            stack_end_stack();
+
+                            return FALSE;
+                        }
+                        (void)vector_pop_back(gStackFrames);
+                        readline_signal();
+                        stack_end_stack();
+                    }
+                    else {
+                        err_msg("There is no object", runinfo->mSName, runinfo->mSLine, command->mArgsRuntime[i]);
+
+                        return FALSE;
+                    }
+                }
+                else {
+                    err_msg("There is no object", runinfo->mSName, runinfo->mSLine, command->mArgsRuntime[i]);
+
+                    return FALSE;
+                }
+            }
+
+            runinfo->mRCode = 0;
+        }
     }
 
     return TRUE;
