@@ -143,6 +143,7 @@ typedef struct {
 
             struct _sObject* mLines;
             enum eLineField mLinesLineField;
+            unsigned int mReadedLineNumber;
         } fdbuf;
     };
 } fd_obj;
@@ -153,14 +154,15 @@ typedef struct {
 
 struct sStatment;
 
-#define STATMENT_REVERSE 0x01 
-#define STATMENT_BACKGROUND 0x02
-#define STATMENT_GLOBALPIPEIN 0x04
-#define STATMENT_GLOBALPIPEOUT 0x08
-#define STATMENT_CONTEXTPIPE 0x10
-#define STATMENT_NORMAL 0x20
-#define STATMENT_OROR 0x40
-#define STATMENT_ANDAND 0x80
+#define STATMENT_REVERSE 0x010000
+#define STATMENT_BACKGROUND 0x020000
+#define STATMENT_GLOBALPIPEIN 0x040000
+#define STATMENT_GLOBALPIPEOUT 0x080000
+#define STATMENT_CONTEXTPIPE 0x100000
+#define STATMENT_NORMAL 0x200000
+#define STATMENT_OROR 0x400000
+#define STATMENT_ANDAND 0x800000
+#define STATMENT_CONTEXTPIPE_NUMBER 0xFFFF
 
 #define STATMENT_COMMANDS_MAX 32
 #define STATMENT_OPTIONS_MAX 8
@@ -190,6 +192,8 @@ typedef struct {
         };
         struct {
             struct _sObject* mBlock;
+            BOOL mDoubleDollar;
+            enum eLineField mLineField;
         };
     };
 } sEnv;
@@ -215,7 +219,7 @@ typedef struct {
     int mRedirectsNum;
     int mRedirectsSize;
 
-    int* mRedirectsFD;   // Used on runtime
+    char** mRedirectsFileNamesRuntime; //runtime
 
     struct _sObject** mBlocks;     // block_obj**
     int mBlocksNum;
@@ -260,13 +264,10 @@ struct _sRunInfo;
 
 typedef struct                // a function object can be treated as block_obj
 {
-    sStatment* mStatments;
-    int mStatmentsNum;
-    int mStatmentsSize;
-    char* mSource;
+    struct _sObject* mBlock;
 
     struct _sObject* mParent;
-    int mParentCount;
+//    int mParentCount;
 
     struct _sObject* mLocalObjects;
     struct _sObject* mArgBlocks;
@@ -275,6 +276,20 @@ typedef struct                // a function object can be treated as block_obj
     struct _sRunInfo* mRunInfo;
 } fun_obj;
 
+typedef struct                // a function object can be treated as block_obj
+{
+    struct _sObject* mBlock;
+
+    struct _sObject* mParent;
+//    int mParentCount;
+
+    struct _sObject* mLocalObjects;
+    struct _sObject* mArgBlocks;
+
+    option_hash_it* mOptions;
+    struct _sRunInfo* mRunInfo;
+} class_obj;
+
 typedef BOOL (*fXyzshNativeFun)(struct _sObject*, struct _sObject*, struct _sRunInfo*);
 
 typedef struct 
@@ -292,11 +307,20 @@ typedef struct {
     BOOL mSuspended;
 } job_obj;
 
+typedef struct _uobject_it {
+   char* mKey;
+   
+   void* mItem;
+   struct _uobject_it* mCollisionIt;
+
+   struct _uobject_it* mNextIt;
+} uobject_it;
+
 typedef struct {          // a user object can be treated like a hash_obj
-   hash_it** mTable;
+   uobject_it** mTable;
    int mTableSize;
 
-   hash_it* mEntryIt;
+   uobject_it* mEntryIt;
 
    int mCounter;
 
@@ -332,6 +356,10 @@ typedef struct {
     fExtObjFreeFun mFreeFun;
 } external_obj;
 
+typedef struct {
+    struct _sObject* mBlock;
+} completion_obj;
+
 #define GC_MARK 0x80000000
 
 #define T_STRING 1
@@ -346,7 +374,7 @@ typedef struct {
 #define T_MEMCHECKER 10
 #define T_FUN 11
 #define T_CLASS 12
-#define T_EXTERNAL 13
+#define T_EXTPROG 13
 #define T_COMPLETION 14
 #define T_EXTOBJ 15
 
@@ -368,6 +396,8 @@ typedef struct _sObject {
         memchecker_obj uMemchecker;
         nfun_obj uNativeFun;
         fun_obj uFunction;
+        class_obj uClass;
+        completion_obj uCompletion;
         external_prog_obj uExternalProg;
         external_obj uExternalObj;
     };
@@ -386,8 +416,10 @@ typedef struct _sObject {
 #define SUOBJECT(o) (o)->uUObject
 #define SMEMCHECKER(o) (o)->uMemchecker
 #define SFUN(o) (o)->uFunction
-#define SEXTERNAL(o) (o)->uExternalProg
+#define SCLASS(o) (o)->uClass
+#define SEXTPROG(o) (o)->uExternalProg
 #define SEXTOBJ(o) (o)->uExternalObj
+#define SCOMPLETION(o) (o)->uCompletion
 
 void gc_init(int pool_size);
 void gc_final();
@@ -415,8 +447,18 @@ sObject* extobj_new_from_gc(void* object, fExtObjMarkFun mark_fun, fExtObjFreeFu
 
 sObject* uobject_new_from_gc(int size, sObject* parent, char* name, BOOL user_object);
 sObject* uobject_new_from_stack(int size, sObject* object, char* name);
+void uobject_put(sObject* self, char* key, void* item);
 void uobject_init(sObject* self);
 void uobject_root_init(sObject* self);
+void uobject_put(sObject* self, char* key, void* item);
+void* uobject_item(sObject* self, char* key);
+void uobject_clear(sObject* self);
+
+uobject_it* uobject_loop_begin(sObject* self);
+void* uobject_loop_item(uobject_it* it);
+char* uobject_loop_key(uobject_it* it);
+uobject_it* uobject_loop_next(uobject_it* it);
+int uobject_count(sObject* self);
 
 #define UOBJECT_NEW_GC(o, o2, o3, o4) uobject_new_from_gc(o, o2, o3, o4)
 #define UOBJECT_NEW_STACK(o, o2, o3) uobject_new_from_stack(o, o2, o3)
@@ -425,14 +467,10 @@ void uobject_delete_gc(sObject* self);
 void uobject_delete_stack(sObject* self);
 int uobject_gc_children_mark(sObject* self);
 
-sObject* external_new_from_gc(char* path, BOOL user_object);
-void external_delete_gc();
+sObject* external_prog_new_from_gc(char* path, BOOL user_object);
+void external_prog_delete_gc();
 
-#define EXTERNAL_NEW_GC(o, o2) external_new_from_gc(o, o2)
-
-//sObject* stackframes_new_from_gc(int first_size, BOOL user_object);
-//void stackframes_delete_gc(sObject* self);
-//#define STACKFRAMES_NEW_GC(size, user_object) stackframes_new_from_gc(size, user_object)
+#define EXTPROG_NEW_GC(o, o2) external_prog_new_from_gc(o, o2)
 
 /// structure used from run, which contains run time info
 typedef struct _sRunInfo {
@@ -459,6 +497,8 @@ BOOL xyzsh_rehash(char* sname, int sline);
 #if defined(HAVE_MIGEMO_H)
 BOOL cmd_migemo_match(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 #endif
+BOOL cmd_kanjicode(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
+BOOL cmd_defined(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 BOOL cmd_funinfo(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 BOOL cmd_readline_read_history(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
 BOOL cmd_readline_write_history(sObject* nextin, sObject* nextout, sRunInfo* runinfo);
@@ -667,7 +707,7 @@ extern sObject* gStackFrames;
 BOOL bufsiz_write(int fd, char* buf, int buf_len);
 
 BOOL load_file(char* fname, sObject* nextin, sObject* nextout, sRunInfo* runinfo, char** argv, int argc);
-void xyzsh_load_file(char* fname, char** argv, int argc);
+BOOL xyzsh_load_file(char* fname, char** argv, int argc, sObject* current_object);
 void xyzsh_opt_c(char* cmd, char** argv, int argc);
 void xyzsh_readline_interface(char* cmdline, int cursor, char** argv, int argc);
 
@@ -687,6 +727,11 @@ int memchecker_item(sObject* self, void* key);
 
 int object_gc_children_mark(sObject* self);
 
+sObject* completion_new_from_gc(sObject* block, BOOL user_object);
+int completion_gc_children_mark(sObject* self);
+
+#define COMPLETION_NEW_GC(o, o2) completion_new_from_gc(o, o2)
+
 sObject* nfun_new_from_gc(fXyzshNativeFun fun, sObject* parent, BOOL user_object);
 #define NFUN_NEW_GC(o, o2, o3) nfun_new_from_gc(o, o2, o3)
 int nfun_gc_children_mark(sObject* self);
@@ -710,19 +755,22 @@ void class_delete_gc(sObject* self);
 void class_delete_stack(sObject* self);
 BOOL class_option_with_argument_item(sObject* self, char* key);
 BOOL class_put_option_with_argument(sObject* self, MANAGED char* key);
+int class_gc_children_mark(sObject* self);
 
 BOOL sCommand_option_item(sCommand* self, char* key);
 char* sCommand_option_with_argument_item(sCommand* self, char* key);
 BOOL sCommand_put_option(sCommand* self, MANAGED char* key);
 BOOL sCommand_put_option_with_argument(sCommand* self, MANAGED char* key, MANAGED char* argument);
 BOOL sCommand_expand_env(sCommand* command, sObject* object, sObject* nextin, sObject* nextout, sRunInfo* runinfo);
-BOOL sCommand_expand_env_redirect(sCommand* command, sObject* nextin, sObject* nextout, sRunInfo* runinfo);
+BOOL sCommand_expand_env_redirect(sCommand* command, sObject* nextin, sRunInfo* runinfo);
 void sCommand_sweep_runtime_info(sCommand* command);
 
 extern sObject* gMemChecker;
 
 extern FILE* gTest;
 
+extern sObject* gInherit;
+
 #define XYZSH_INHERIT_MAX 32
 
 sObject* access_object(char* name, sObject** current, sObject* running_object);
@@ -755,11 +803,10 @@ void clear_matching_info_variable();
 #define REDIRECT_APPEND 2
 #define REDIRECT_OUT 3
 
-void xyzsh_shell(char* cmdline, char* source_name, sObject* nextin, sObject* nextout, BOOL add_history, fXyzshJobDone xyzsh_job_done_, char** argv, int argc);
-void xyzsh_readline_interface_onetime(char* cmdline, int cursor_point, char* source_name, char** argv, int argc, fXyzshJobDone xyzsh_job_done_);
+BOOL xyzsh_readline_interface_onetime(int* rcode, char* cmdline, int cursor_point, char* source_name, char** argv, int argc, fXyzshJobDone xyzsh_job_done_);
 char* xyzsh_job_title(int n);
 int xyzsh_job_num();
-int xyzsh_run(sObject* block, char* source_name, fXyzshJobDone xyzsh_job_done_, sObject* nextin, sObject* nextout, int argc, char** argv);
+BOOL xyzsh_run(int* rcode, sObject* block, char* source_name, fXyzshJobDone xyzsh_job_done_, sObject* nextin, sObject* nextout, int argc, char** argv, sObject* current_object);
 
 #include <stdarg.h>
 
@@ -769,5 +816,7 @@ void readline_write_history();
 void readline_read_history();
 void xyzsh_read_rc_core(char* path);
 
+extern sObject* gStackFrames;
+
 #endif
 
